@@ -1,7 +1,6 @@
-/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*- */
 /* vvmplayer-preferences-window.h
  *
- * Copyright 2021 Chris Talbot <chris@talbothome.com>
+ * Copyright 2021-2022 Chris Talbot
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,22 +15,19 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Author(s):
- *   Chris Talbot <chris@talbothome.com>
- *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #pragma once
 
-#include <handy.h>
+#include <adwaita.h>
 
 G_BEGIN_DECLS
 
-#define HDY_TYPE_VVM_PREFERENCES_WINDOW (vvm_preferences_window_get_type())
+#define ADW_TYPE_DEMO_PREFERENCES_WINDOW (vvm_player_preferences_window_get_type ())
 
-G_DECLARE_FINAL_TYPE (VvmPreferencesWindow, vvm_preferences_window, HDY, VVM_PREFERENCES_WINDOW, HdyPreferencesWindow)
+G_DECLARE_FINAL_TYPE (VvmplayerPreferencesWindow, vvm_player_preferences_window, ADW, VVMPLAYER_PREFERENCES_WINDOW, AdwPreferencesWindow)
 
-VvmPreferencesWindow *vvm_preferences_window_new (void);
+VvmplayerPreferencesWindow *vvm_player_preferences_window_new (void);
 
 G_END_DECLS
